@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2014 by Dominique Dumont.
+# This software is Copyright (c) 2015 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::LeafEditor;
-$Config::Model::Tk::LeafEditor::VERSION = '1.344';
+$Config::Model::Tk::LeafEditor::VERSION = '1.345';
 use strict;
 use warnings;
 use Carp;
@@ -46,7 +46,7 @@ sub Populate {
     my $inst = $leaf->instance;
     my $vt   = $leaf->value_type;
     $logger->info("Creating leaf editor for value_type $vt");
-    $cw->{value} = $leaf->fetch( check => 'no' );
+    $cw->{value} = $leaf->fetch( check => 'no', mode => 'user' );
     $logger->info( "Creating leaf editor with error " . $leaf->error_msg );
 
     $cw->add_header( Edit => $leaf )->pack(@fx);
@@ -248,23 +248,39 @@ sub delete {
 # can be used without parameters to store value from widget into config tree
 sub store {
     my $cw = shift;
-    my $v  = $cw->try(@_);
-    return unless defined $v;
+    my $e_w = $cw->{e_widget};
+
+    # tk widget use a reference
+    my $v = defined $e_w
+            ? $e_w->get( '1.0', 'end' )
+            : $cw->{value};
+
+    $v = '' unless defined $v;
+    chomp $v;
 
     print "Storing '$v'\n";
+    my $leaf = $cw->{leaf};
 
-    eval { $cw->{leaf}->store($v); };
+    eval { $leaf->store($v); };
 
     if ($@) {
-        $cw->Dialog(
+        $cw->Dialog (
             -title => 'Value error',
             -text  => $@->as_string,
         )->Show;
+        $cw->reset_value;
+    }
+    elsif ($leaf->has_error) {
+        $cw->Dialog (
+            -title => 'Value error',
+            -text  => "Cannot store the value:\n* ".join("\n* ",$leaf->all_errors),
+        )->Show;
+        $cw->reset_value;
     }
     else {
         # trigger redraw of Tk Tree
         $cw->{store_cb}->();
-        $cw->update_warning( $cw->{leaf} );
+        $cw->update_warning( $leaf );
     }
 }
 
